@@ -2,7 +2,7 @@ use std::{fmt::Write, hash::Hash, marker::PhantomData, sync::Arc, time::SystemTi
 
 use tracing::Level;
 
-use elfo_core::{_priv::ObjectMeta, trace_id::TraceId};
+use elfo_core::{trace_id::TraceId, ActorMeta};
 
 pub(crate) trait Formatter<T: ?Sized> {
     fn fmt(dest: &mut String, v: &T);
@@ -61,16 +61,15 @@ impl Formatter<TraceId> for TraceId {
     }
 }
 
-// ObjectMeta
+// ActorMeta
 
-impl Formatter<Arc<ObjectMeta>> for Arc<ObjectMeta> {
-    fn fmt(out: &mut String, v: &Arc<ObjectMeta>) {
-        if let Some(key) = v.key.as_ref() {
-            out.push_str(&v.group);
+impl Formatter<Arc<ActorMeta>> for Arc<ActorMeta> {
+    fn fmt(out: &mut String, v: &Arc<ActorMeta>) {
+        out.push_str(&v.group);
+
+        if !v.key.is_empty() {
             out.push('.');
-            out.push_str(key);
-        } else {
-            out.push_str(&v.group);
+            out.push_str(&v.key);
         }
     }
 }
@@ -126,7 +125,7 @@ pub(crate) struct Location;
 
 impl Formatter<(&'static str, u32)> for Location {
     fn fmt(out: &mut String, v: &(&'static str, u32)) {
-        let _ = write!(out, "@location={}:{}", v.0, v.1);
+        let _ = write!(out, "_location={}:{}", reduce_location(v.0), v.1);
     }
 }
 
@@ -136,7 +135,12 @@ pub(crate) struct ColoredLocation;
 
 impl Formatter<(&'static str, u32)> for ColoredLocation {
     fn fmt(out: &mut String, v: &(&'static str, u32)) {
-        let _ = write!(out, "\x1b[1m@location\x1b[22m={}:{}", v.0, v.1);
+        let _ = write!(
+            out,
+            "\x1b[1m_location\x1b[22m={}:{}",
+            reduce_location(v.0),
+            v.1
+        );
     }
 }
 
@@ -146,7 +150,7 @@ pub(crate) struct Module;
 
 impl Formatter<str> for Module {
     fn fmt(out: &mut String, v: &str) {
-        out.push_str("@module=");
+        out.push_str("_module=");
         out.push_str(v);
     }
 }
@@ -157,7 +161,7 @@ pub(crate) struct ColoredModule;
 
 impl Formatter<str> for ColoredModule {
     fn fmt(out: &mut String, v: &str) {
-        out.push_str("\x1b[1m@module\x1b[22m=");
+        out.push_str("\x1b[1m_module\x1b[22m=");
         out.push_str(v);
     }
 }
@@ -203,3 +207,22 @@ impl<T: Hash, I: Formatter<T>> Formatter<T> for ColoredByHash<I> {
 fn clamp(v: f64) -> u8 {
     v.max(0.).min(255.) as u8
 }
+
+fn reduce_location(s: &str) -> &str {
+    // $CARGO_HOME/registry/src/$REG-HASH
+    s.split_once("/registry/src/")
+        .and_then(|(_, s)| s.split_once('/'))
+        .map_or(s, |(_, s)| s)
+}
+
+#[test]
+fn it_reduces_location() {
+    assert_eq!(
+        reduce_location("/cache/.cargo/registry/src/github.com-xyz/foo-0.1.0/src/bar/baz.rs"),
+        "foo-0.1.0/src/bar/baz.rs"
+    );
+    assert_eq!(
+        reduce_location("actors/foo/src/bar/baz.rs"),
+        "actors/foo/src/bar/baz.rs"
+    );
+}
